.. Copyright 2015 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Module reahl.web.datatable
--------------------------

.. automodule:: reahl.web.datatable


DataTable
"""""""""

.. sidebar:: Examples

   - tutorial.datatable

   Get a copy of an example by running:

   .. code-block:: bash

      reahl example <examplename>

.. autoclass:: DataTable
   :members:


